@@ -28,6 +28,8 @@
 
 #include <Lum/Config/Config.h>
 
+#include <Lum/Def/OneOfMany.h>
+
 #include <Lum/Combo.h>
 #include <Lum/Label.h>
 #include <Lum/Multi.h>
@@ -93,22 +95,29 @@ Settings::Settings()
 
 Lum::Object* Settings::GetContent()
 {
+  Lum::Def::OneOfMany choiceDef(Lum::Def::Desc(L"Choice"),
+                                choice,choices);
+
+  Lum::Def::OneOfMany presetDef(Lum::Def::Desc(L"Preset"),
+                                preset,presets);
+
   return Lum::VPanel::Create(true,true)
            ->Add(Lum::Label::Create(true,false)
                  ->AddLabel(L"Choice:",
-                            Lum::IndexCombo::Create(choice,choices,true,false)))
+                            Lum::OS::display->GetBehaviour()->GetOneOfManyControl(choiceDef,true,false)))
             ->AddSpace()
             ->Add(Lum::Multi::Create(setting,true,true)
                   ->Append(Lum::Label::Create(true,false)
                            ->AddLabel(L"Preset:",
-                                      Lum::IndexCombo::Create(preset,presets,true,false)))
+                                      Lum::OS::display->GetBehaviour()->GetOneOfManyControl(presetDef,true,false)))
                   ->Append(Lum::Text::Create(L"Scale will be calculated based on display DPI settings.\n"
                                              L"\n"
                                              L"Depending of the quality of the DPI settings, scale\n"
                                              L"may thus be inprecise!"))
                   ->Append(Lum::Label::Create(true,false)
                            ->AddLabel(L"Display width in unit:",
-                                      Lum::String::Create(factor,true,false))
+                                      Lum::String::Create(factor,true,false)
+                                      ->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typePosFloat)))
                            ->AddLabel(L"Name of unit:",
                                       Lum::String::Create(unit,true,false))
                   )
